==> RoughlyEnoughItems-3.2.28-sources.jar: me/shedaniel/rei/gui/ConfigReloadingScreen.java <==
/*
 * Roughly Enough Items by Danielshe.
 * Licensed under the MIT License.
 */

package me.shedaniel.rei.gui;

import me.shedaniel.rei.api.RecipeHelper;
import me.shedaniel.rei.api.annotations.Internal;
import net.minecraft.class_1074;
import net.minecraft.class_156;
import net.minecraft.class_333;
import net.minecraft.class_437;

@Deprecated
@Internal
public class ConfigReloadingScreen extends class_437 {
    
    private class_437 parent;
    
    public ConfigReloadingScreen(class_437 parent) {
        super(class_333.field_18967);
        this.parent = parent;
    }
    
    @Override
    public boolean shouldCloseOnEsc() {
        return false;
    }
    
    @Override
    public void render(int int_1, int int_2, float float_1) {
        this.renderDirtBackground(0);
        if (!RecipeHelper.getInstance().arePluginsLoading())
            minecraft.method_1507(parent);
        this.drawCenteredString(this.font, class_1074.method_4662("text.rei.config.is.reloading"), this.width / 2, this.height / 2 - 50, 16777215);
        String string_3;
        switch ((int) (class_156.method_658() / 300L % 4L)) {
            case 0:
            default:
                string_3 = "O o o";
                break;
            case 1:
            case 3:
                string_3 = "o O o";
                break;
            case 2:
                string_3 = "o o O";
        }
        this.drawCenteredString(this.font, string_3, this.width / 2, this.height / 2 - 41, 8421504);
        super.render(int_1, int_2, float_1);
    }
    
    @Override
    public boolean isPauseScreen() {
        return false;
    }
}

==> RoughlyEnoughItems-3.3.15-sources.jar: me/shedaniel/rei/gui/ConfigReloadingScreen.java <==
/*
 * Roughly Enough Items by Danielshe.
 * Licensed under the MIT License.
 */

package me.shedaniel.rei.gui;

import me.shedaniel.rei.api.RecipeHelper;
import net.minecraft.class_1074;
import net.minecraft.class_156;
import net.minecraft.class_333;
import net.minecraft.class_437;
import org.jetbrains.annotations.ApiStatus;

@ApiStatus.Internal
public class ConfigReloadingScreen extends class_437 {
    
    private class_437 parent;
    
    public ConfigReloadingScreen(class_437 parent) {
        super(class_333.field_18967);
        this.parent = parent;
    }
    
    @Override
    public boolean shouldCloseOnEsc() {
        return false;
    }
    
    @Override
    public void render(int int_1, int int_2, float float_1) {
        this.renderDirtBackground(0);
        if (!RecipeHelper.getInstance().arePluginsLoading())
            minecraft.method_1507(parent);
        this.drawCenteredString(this.font, class_1074.method_4662("text.rei.config.is.reloading"), this.width / 2, this.height / 2 - 50, 16777215);
        String string_3;
        switch ((int) (class_156.method_658() / 300L % 4L)) {
            case 0:
            default:
                string_3 = "O o o";
                break;
            case 1:
            case 3:
                string_3 = "o O o";
                break;
            case 2:
                string_3 = "o o O";
        }
        this.drawCenteredString(this.font, string_3, this.width / 2, this.height / 2 - 41, 8421504);
        super.render(int_1, int_2, float_1);
    }
    
    @Override
    public boolean isPauseScreen() {
        return false;
    }
}
